Derive.Migration behaviour (derive v0.5.4)

Copy Markdown View Source

@todo add documentation

Summary

Callbacks

@todo add documentation

@todo add documentation

Functions

@todo add documentation

@todo add documentation, make sure to cover the points below

@todo add documentation, make sure to cover the points below

Callbacks

down()

(since 0.1.0)
@callback down() :: term()

@todo add documentation

up()

(since 0.1.0)
@callback up() :: term()

@todo add documentation

Functions

__using__(_)

(since 0.1.0) (macro)

@todo add documentation

down(n)

(since 0.1.0) (macro)

@todo add documentation, make sure to cover the points below

Key points:

  • sequentially rolls back all migrations down to the given nth version.

up(n)

(since 0.1.0) (macro)

@todo add documentation, make sure to cover the points below

Key points:

  • sequentially runs all migrations up to the given nth version.